
###to use: python membrane_thickness.py -str ../lipids-water.gro -sel PO4 

import sys, os, argparse
import MDAnalysis as mda
import pandas as pd
import numpy as np


def bilayer_center(GRO,SEL):

  import warnings
  # suppress some MDAnalysis warnings about reading str files
  warnings.filterwarnings('ignore')

  u = mda.Universe(GRO)
  phosphates = u.select_atoms("name "+str(SEL))
  bilayer_center = phosphates.positions[:,2].mean()/10 #calculate mean z positions in nm
  print("Bilayer center:  %.2f nm" % bilayer_center)


if __name__ == "__main__":
  if len(sys.argv)<3:
    raise SystemExit("Reads in .gro and .xtc files and calculates membrane thickness")
  parser = argparse.ArgumentParser()
  parser.add_argument('-str', '--structure_file', nargs='?')
  parser.add_argument('-sel', '--atom_selection', nargs='?') 
          
  parsed = parser.parse_args()
  GRO = parsed.__dict__['structure_file']
  SEL = parsed.__dict__['atom_selection']

  bilayer_center(GRO,SEL)
