# First generate an index file that selects beads of a specific lipid type
# Here our example is SAP6:

gmx make_ndx -f ref-final.gro -o sap6-index.ndx < 3.example-index-selection.txt


# Next, calculate the bilayer center along z. The gmx densmap command will use this value (in nm)
# to choose lipids in individual leaflets
echo `python 3.bilayer_center.py -str ref-final.gro -sel PO4` | grep -Eo '[+-]?[0-9]+([.][0-9]+)?' > a
bilayer_center_value_in_nm=`paste a`
rm a
# Next, use gmx densmap to calculate the 2D density  of SAP6 in the lower leaflet
# lower leaflet is defined as lipids whose z coordinates lie between [0.0, bilayer_center_value_in_nm]
# as defined with xmin and xmax options 
# here bilayer_center_value_in_nm = 7.65 nm

gmx densmap -f all-final.xtc -s ref-final.gro -n sap6-index.ndx -bin 0.005 -aver z -xmin 0.0 -xmax ${bilayer_center_value_in_nm} -dmin 0 -dmax 0 -unit count -od densmap_sap6_lower_leaflet.dat
# To visualize the data, use the given R script that takes the output of `gmx densmap` (without the `.dat` extension) 
# and the simulation box size along x and y (in nm) as inputs with the given order:

R < 3.plot-fingerprints.R --no-save --args "densmap_sap6_lower_leaflet" 40
